@@ -1509,8 +1509,9 @@ def cat(*list_of_tensors, dim=None, **kwargs):
         else: dim = 0
     if len(list_of_tensors) == 1 and isinstance(list_of_tensors[0], (tuple, list)):
         list_of_tensors = list_of_tensors[0]
-    self = [t for t in list_of_tensors if isinstance(t, Tensor)][0]
-    return torch.cat(list_of_tensors, dim, **kwargs).as_subclass(Tensor).special_from_(self)
+    self = [t for t in list_of_tensors if isinstance(t, Tensor)]
+    if len(self) == 0: return torch.cat(list_of_tensors, dim, **kwargs).as_subclass(Tensor).special_from_()
+    return torch.cat(list_of_tensors, dim, **kwargs).as_subclass(Tensor).special_from_(self[0])
 
 def stack(*list_of_tensors, dim=None, **kwargs):
     if dim is None:
@@ -1522,8 +1523,9 @@ def stack(*list_of_tensors, dim=None, **kwargs):
         else: dim = 0
     if len(list_of_tensors) == 1 and isinstance(list_of_tensors[0], (tuple, list)):
         list_of_tensors = list_of_tensors[0]
-    self = [t for t in list_of_tensors if isinstance(t, Tensor)][0]
-    return torch.stack(list_of_tensors, dim, **kwargs).as_subclass(Tensor).set_special_(special=[x + 1 if x >= dim else x for x in self._special])
+    self = [t for t in list_of_tensors if isinstance(t, Tensor)]
+    if len(self) == 0: return torch.stack(list_of_tensors, dim, **kwargs).as_subclass(Tensor).special_from_()
+    return torch.stack(list_of_tensors, dim, **kwargs).as_subclass(Tensor).set_special_(special=[x + 1 if x >= dim else x for x in self[0]._special])
 
 @params
 def t(tensor: Array.Torch):
